==> openshift-model-operator-5.12.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConfigStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.ConfigStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConfigStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ConfigStatus,io.fabric8.openshift.api.model.operator.v1.ConfigStatusBuilder>{
  public ConfigStatusBuilder() {
    this(false);
  }
  public ConfigStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ConfigStatus(), validationEnabled);
  }
  public ConfigStatusBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigStatusBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConfigStatus(), validationEnabled);
  }
  public ConfigStatusBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ConfigStatus instance) {
    this(fluent, instance, false);
  }
  public ConfigStatusBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ConfigStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigStatusBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigStatus instance) {
    this(instance,false);
  }
  public ConfigStatusBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ConfigStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ConfigStatus build() {
    ConfigStatus buildable = new ConfigStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigStatusBuilder that = (ConfigStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConfigStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConfigStatusBuilder extends ConfigStatusFluentImpl<ConfigStatusBuilder> implements VisitableBuilder<ConfigStatus,ConfigStatusBuilder>{
  public ConfigStatusBuilder() {
    this(false);
  }
  public ConfigStatusBuilder(Boolean validationEnabled) {
    this(new ConfigStatus(), validationEnabled);
  }
  public ConfigStatusBuilder(ConfigStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigStatusBuilder(ConfigStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConfigStatus(), validationEnabled);
  }
  public ConfigStatusBuilder(ConfigStatusFluent<?> fluent,ConfigStatus instance) {
    this(fluent, instance, false);
  }
  public ConfigStatusBuilder(ConfigStatusFluent<?> fluent,ConfigStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigStatusBuilder(ConfigStatus instance) {
    this(instance,false);
  }
  public ConfigStatusBuilder(ConfigStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConfigStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ConfigStatus build() {
    ConfigStatus buildable = new ConfigStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
